@@ -70,7 +70,9 @@ sub run {
         check_init_script($info, $script, $services);
     }
 
+    check_timers($info);
     check_maintainer_scripts($info);
+
     return;
 }
 
@@ -118,9 +120,9 @@ sub check_init_script {
     my $fh = $file->open;
     while (<$fh>) {
         lstrip;
-        if ($. == 1 and m{\A [#]! \s*/lib/init/init-d-script}xsm) {
-            $lsb_source_seen = 1;
-        }
+        $lsb_source_seen = 1
+          if $. == 1
+          and m{\A [#]! \s* (?:/usr/bin/env)? \s* /lib/init/init-d-script}xsm;
         if (m,#.*Default-Start:.*S,) {
             $is_rcs_script = 1;
         }
@@ -354,6 +356,19 @@ sub extract_service_file_values {
     return @values;
 }
 
+sub check_timers {
+    my ($info) = @_;
+
+    return if any { m,^/lib/systemd/system/\.timer$, } $info->sorted_index;
+
+    for my $file ($info->sorted_index) {
+        tag 'missing-systemd-timer-for-cron-script', $file
+          if $file->dirname =~ m,^etc/cron\.[^\/]+/$,;
+    }
+
+    return;
+}
+
 sub check_maintainer_scripts {
     my ($info) = @_;
 
